==> estateplat-common-1.2.3-20180620.083639-127-sources.jar: cn/gtmap/estateplat/model/exchange/national/InfApplyJgzz.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/9/28
 * @description 结果证照信息
 */
@Table(name = "inf_apply_jgzz")
public class InfApplyJgzz {
    @Id
    private String no;//唯一标识
    private String internal_no;//部门内部办件编号
    private String mould_id;//证照实施清单主键
    private String dzzz_no;//电子证照编号
    private String zz_bh;//纸质证照编号
    private Date bz_date;//颁证时间
    private Date star_time;//有效期（起始）
    private Date end_time;//有效期（截止）
    private String dept_name;//颁证单位
    private String user_name;//持证者
    private String user_type;//持证者类型
    private String user_paper_type;//持证者证件类型
    private String user_no;//持证者号码
    private String zz_type;//证照分类
    private String individuation;//XML证照封装信息
    private String zz_file;//电子证照文件
    private String xk_zl;//种类
    private String xk_splb;//审批类别
    private String xk_nr;//许可内容
    private Date create_date;//创建时间
    private String state;//状态
    private Date sync_date;//同步时间
    private String sync_sign;//同步标识
    private String sync_error_desc;//同步错误信息

    private String cert_info;//json证照照面信息

    public String getNo() {
        return no;
    }

    public void setNo(String no) {
        this.no = no;
    }

    public String getInternal_no() {
        return internal_no;
    }

    public void setInternal_no(String internal_no) {
        this.internal_no = internal_no;
    }

    public String getMould_id() {
        return mould_id;
    }

    public void setMould_id(String mould_id) {
        this.mould_id = mould_id;
    }

    public String getDzzz_no() {
        return dzzz_no;
    }

    public void setDzzz_no(String dzzz_no) {
        this.dzzz_no = dzzz_no;
    }

    public String getZz_bh() {
        return zz_bh;
    }

    public void setZz_bh(String zz_bh) {
        this.zz_bh = zz_bh;
    }

    public Date getBz_date() {
        return bz_date;
    }

    public void setBz_date(Date bz_date) {
        this.bz_date = bz_date;
    }

    public Date getStar_time() {
        return star_time;
    }

    public void setStar_time(Date star_time) {
        this.star_time = star_time;
    }

    public Date getEnd_time() {
        return end_time;
    }

    public void setEnd_time(Date end_time) {
        this.end_time = end_time;
    }

    public String getDept_name() {
        return dept_name;
    }

    public void setDept_name(String dept_name) {
        this.dept_name = dept_name;
    }

    public String getUser_name() {
        return user_name;
    }

    public void setUser_name(String user_name) {
        this.user_name = user_name;
    }

    public String getUser_type() {
        return user_type;
    }

    public void setUser_type(String user_type) {
        this.user_type = user_type;
    }

    public String getUser_paper_type() {
        return user_paper_type;
    }

    public void setUser_paper_type(String user_paper_type) {
        this.user_paper_type = user_paper_type;
    }

    public String getUser_no() {
        return user_no;
    }

    public void setUser_no(String user_no) {
        this.user_no = user_no;
    }

    public String getZz_type() {
        return zz_type;
    }

    public void setZz_type(String zz_type) {
        this.zz_type = zz_type;
    }

    public String getIndividuation() {
        return individuation;
    }

    public void setIndividuation(String individuation) {
        this.individuation = individuation;
    }

    public String getZz_file() {
        return zz_file;
    }

    public void setZz_file(String zz_file) {
        this.zz_file = zz_file;
    }

    public String getXk_zl() {
        return xk_zl;
    }

    public void setXk_zl(String xk_zl) {
        this.xk_zl = xk_zl;
    }

    public String getXk_splb() {
        return xk_splb;
    }

    public void setXk_splb(String xk_splb) {
        this.xk_splb = xk_splb;
    }

    public String getXk_nr() {
        return xk_nr;
    }

    public void setXk_nr(String xk_nr) {
        this.xk_nr = xk_nr;
    }

    public Date getCreate_date() {
        return create_date;
    }

    public void setCreate_date(Date create_date) {
        this.create_date = create_date;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public Date getSync_date() {
        return sync_date;
    }

    public void setSync_date(Date sync_date) {
        this.sync_date = sync_date;
    }

    public String getSync_sign() {
        return sync_sign;
    }

    public void setSync_sign(String sync_sign) {
        this.sync_sign = sync_sign;
    }

    public String getSync_error_desc() {
        return sync_error_desc;
    }

    public void setSync_error_desc(String sync_error_desc) {
        this.sync_error_desc = sync_error_desc;
    }

    public String getCert_info() {
        return cert_info;
    }

    public void setCert_info(String cert_info) {
        this.cert_info = cert_info;
    }
}

==> estateplat-common-1.2.4-20190312.015045-117-sources.jar: cn/gtmap/estateplat/model/exchange/national/InfApplyJgzz.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/9/28
 * @description 结果证照信息
 */
@Table(name = "inf_apply_jgzz")
public class InfApplyJgzz {
    @Id
    private String no;//唯一标识
    private String internal_no;//部门内部办件编号
    private String mould_id;//证照实施清单主键
    private String dzzz_no;//电子证照编号
    private String zz_bh;//纸质证照编号
    private Date bz_date;//颁证时间
    private Date star_time;//有效期（起始）
    private Date end_time;//有效期（截止）
    private String dept_name;//颁证单位
    private String user_name;//持证者
    private String user_type;//持证者类型
    private String user_paper_type;//持证者证件类型
    private String user_no;//持证者号码
    private String zz_type;//证照分类
    private String individuation;//XML证照封装信息
    private String zz_file;//电子证照文件
    private String xk_zl;//种类
    private String xk_splb;//审批类别
    private String xk_nr;//许可内容
    private Date create_date;//创建时间
    private String state;//状态
    private Date sync_date;//同步时间
    private String sync_sign;//同步标识
    private String sync_error_desc;//同步错误信息
    private String cert_info;//json证照照面信息
    private String proid;//业务号

    public String getNo() {
        return no;
    }

    public void setNo(String no) {
        this.no = no;
    }

    public String getInternal_no() {
        return internal_no;
    }

    public void setInternal_no(String internal_no) {
        this.internal_no = internal_no;
    }

    public String getMould_id() {
        return mould_id;
    }

    public void setMould_id(String mould_id) {
        this.mould_id = mould_id;
    }

    public String getDzzz_no() {
        return dzzz_no;
    }

    public void setDzzz_no(String dzzz_no) {
        this.dzzz_no = dzzz_no;
    }

    public String getZz_bh() {
        return zz_bh;
    }

    public void setZz_bh(String zz_bh) {
        this.zz_bh = zz_bh;
    }

    public Date getBz_date() {
        return bz_date;
    }

    public void setBz_date(Date bz_date) {
        this.bz_date = bz_date;
    }

    public Date getStar_time() {
        return star_time;
    }

    public void setStar_time(Date star_time) {
        this.star_time = star_time;
    }

    public Date getEnd_time() {
        return end_time;
    }

    public void setEnd_time(Date end_time) {
        this.end_time = end_time;
    }

    public String getDept_name() {
        return dept_name;
    }

    public void setDept_name(String dept_name) {
        this.dept_name = dept_name;
    }

    public String getUser_name() {
        return user_name;
    }

    public void setUser_name(String user_name) {
        this.user_name = user_name;
    }

    public String getUser_type() {
        return user_type;
    }

    public void setUser_type(String user_type) {
        this.user_type = user_type;
    }

    public String getUser_paper_type() {
        return user_paper_type;
    }

    public void setUser_paper_type(String user_paper_type) {
        this.user_paper_type = user_paper_type;
    }

    public String getUser_no() {
        return user_no;
    }

    public void setUser_no(String user_no) {
        this.user_no = user_no;
    }

    public String getZz_type() {
        return zz_type;
    }

    public void setZz_type(String zz_type) {
        this.zz_type = zz_type;
    }

    public String getIndividuation() {
        return individuation;
    }

    public void setIndividuation(String individuation) {
        this.individuation = individuation;
    }

    public String getZz_file() {
        return zz_file;
    }

    public void setZz_file(String zz_file) {
        this.zz_file = zz_file;
    }

    public String getXk_zl() {
        return xk_zl;
    }

    public void setXk_zl(String xk_zl) {
        this.xk_zl = xk_zl;
    }

    public String getXk_splb() {
        return xk_splb;
    }

    public void setXk_splb(String xk_splb) {
        this.xk_splb = xk_splb;
    }

    public String getXk_nr() {
        return xk_nr;
    }

    public void setXk_nr(String xk_nr) {
        this.xk_nr = xk_nr;
    }

    public Date getCreate_date() {
        return create_date;
    }

    public void setCreate_date(Date create_date) {
        this.create_date = create_date;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public Date getSync_date() {
        return sync_date;
    }

    public void setSync_date(Date sync_date) {
        this.sync_date = sync_date;
    }

    public String getSync_sign() {
        return sync_sign;
    }

    public void setSync_sign(String sync_sign) {
        this.sync_sign = sync_sign;
    }

    public String getSync_error_desc() {
        return sync_error_desc;
    }

    public void setSync_error_desc(String sync_error_desc) {
        this.sync_error_desc = sync_error_desc;
    }

    public String getCert_info() {
        return cert_info;
    }

    public void setCert_info(String cert_info) {
        this.cert_info = cert_info;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
